@@ -2,6 +2,7 @@ import logging
 from typing import Optional, TYPE_CHECKING
 from django.conf import settings
 from .choices import CONTEXT, SYNCMODES
+
 if TYPE_CHECKING:
     from .models import SyncableModel
 
@@ -13,7 +14,10 @@ from .constants import (
 logger = logging.getLogger(__name__)
 
 
-def skip_publication(record_data: Optional[dict] = None, record: Optional['SyncableModel'] = None):
+def skip_publication(
+    record_data: dict | None = None,
+    record: Optional['SyncableModel'] = None,
+) -> bool:
     """
     Some events should not be published back to the Concordia MQ.
     Examine the event data to determine if the change should be
