@@ -1,7 +1,7 @@
-from django.utils.translation import gettext_lazy as _
+from django.utils.translation import gettext_lazy as tr
 from django.apps import AppConfig
 
 
 class ConcordiaConfig(AppConfig):
     name = 'concordia'
-    verbose_name = _('Concordia Sync')
+    verbose_name = tr('Concordia Sync')
