@@ -3,7 +3,8 @@ from lchttp.json import json_loads
 from pgpubsub.channel import BaseChannel
 from pgpubsub.listeners import _trigger_action_listener
 import pgtrigger
-from typing import Callable, Type, TYPE_CHECKING, Union
+from typing import Callable, Optional, TYPE_CHECKING
+from uuid import UUID
 
 from django.conf import settings
 from django.utils.module_loading import import_string
@@ -11,8 +12,8 @@ from django.utils.module_loading import import_string
 from .rooms import RoomChannelRegistry
 
 if TYPE_CHECKING:
-    from .models import ConcordEvent
-    from rest_framework.serializers import ModelSerializer
+    from .models import ConcordEvent, SyncableModel
+    from console_base.api.serializers import LCModelSerializer
 
 ROOM_CHANNEL_REGISTRY = RoomChannelRegistry()
 try:
@@ -30,15 +31,16 @@ class ConcordTriggerChannel(BaseChannel):
     Trigger for Concord Event history, deserializing
     JSON record data to a dict.
     """
+
     model: 'ConcordEvent'
     new: dict
 
     # attributes for handling Clarion messages
-    serializer: 'ModelSerializer'
+    serializer: type['LCModelSerializer']
 
     @classmethod
-    def room_name(cls):
-        if (name := cls.model._meta.model_name).startswith('concord_'):
+    def room_name(cls) -> str:
+        if (name := cls.model._meta.model_name or '').startswith('concord_'):
             return name[8:]
         return name
 
@@ -48,13 +50,13 @@ class ConcordTriggerChannel(BaseChannel):
         Postgres LISTEN protocol accepts channel names
         which are at most 63 characters long.
         """
-        model_name = cls.model().__class__.__name__.lower()
+        model_name = cls.model().__class__.__name__.lower()  # type: ignore[operator]
         if model_name.endswith('concordevent'):
             model_name = model_name[:-12]
         return f'concord_{model_name}'
 
     @classmethod
-    def deserialize(cls, payload: Union[dict, str]) -> dict:
+    def deserialize(cls, payload: dict | str) -> dict:
         """
         Override method to use faster JSON parsing and to return
         a dict that will correctly initialize Channel dataclass.
@@ -79,7 +81,11 @@ class ConcordTriggerChannel(BaseChannel):
         # ROOM_CHANNEL_REGISTRY[cls.room_name] = cls
 
     @classmethod
-    def publish_room_names(cls, record=None, origin_appliance_cid='') -> list[str]:
+    def publish_room_names(
+        cls,
+        record: Optional['SyncableModel'] = None,
+        origin_appliance_cid: str | UUID = '',
+    ) -> list[str]:
         """
         Return all Room Names to Publish new Messages.
 
@@ -118,7 +124,7 @@ class ConcordTriggerChannel(BaseChannel):
         raise NotImplementedError('deploy room name not calculated yet')
 
 
-def post_update_event_listener(channel: Union[Type[ConcordTriggerChannel], str]):
+def post_update_event_listener(channel: type[ConcordTriggerChannel] | str):  # type: ignore[no-untyped-def]
     return _trigger_action_listener(
         channel=channel,
         when=pgtrigger.After,
@@ -126,7 +132,7 @@ def post_update_event_listener(channel: Union[Type[ConcordTriggerChannel], str])
     )
 
 
-def post_insert_event_listener(channel: Union[Type[ConcordTriggerChannel], str]):
+def post_insert_event_listener(channel: type[ConcordTriggerChannel] | str):  # type: ignore[no-untyped-def]
     return _trigger_action_listener(
         channel=channel,
         when=pgtrigger.After,
@@ -134,7 +140,7 @@ def post_insert_event_listener(channel: Union[Type[ConcordTriggerChannel], str])
     )
 
 
-def post_delete_event_listener(channel: Union[Type[ConcordTriggerChannel], str]):
+def post_delete_event_listener(channel: type[ConcordTriggerChannel] | str):  # type: ignore[no-untyped-def]
     return _trigger_action_listener(
         channel=channel,
         when=pgtrigger.After,
