@@ -1,13 +1,13 @@
 from console_base.choices import LCTextChoicesMixin
 from django.db.models import TextChoices
-from django.utils.translation import gettext_lazy as _
+from django.utils.translation import gettext_lazy as tr
 
 
 # ---------------------------------------------------------------------------
 class CONTEXT(LCTextChoicesMixin, TextChoices):
-    Event = 'pgh_context', 'Context from local Concord Event'
-    Origin = 'origin_context', "Subscriber's original Concord Event Context"
-    Keys = 'keys', "Context Keys from Subscriber's Event Context"
+    Event = 'pgh_context', tr('Context from local Concord Event')
+    Origin = 'origin_context', tr("Subscriber's original Concord Event Context")
+    Keys = 'keys', tr("Context Keys from Subscriber's Event Context")
 
 
 # ---------------------------------------------------------------------------
@@ -16,8 +16,9 @@ class SYNCMODES(LCTextChoicesMixin, TextChoices):
     Should records be deleted on the local console only,
     or synchronized among all the consoles?
     """
-    Sync = 'sync', _('Sync Everywhere')
-    Local = 'local', _('Local System Only')
+
+    Sync = 'sync', tr('Sync Everywhere')
+    Local = 'local', tr('Local System Only')
 
 
 # ---------------------------------------------------------------------------
@@ -30,5 +31,5 @@ class CRUD(LCTextChoicesMixin, TextChoices):
 
 # ---------------------------------------------------------------------------
 class ORIGIN_SERVER(LCTextChoicesMixin, TextChoices):
-    CID = 'origin_server_cid', _('Origin Appliance / Server CID')
-    Name = 'origin_server_name', _('Origin Appliance / Server Name')
+    CID = 'origin_server_cid', tr('Origin Appliance / Server CID')
+    Name = 'origin_server_name', tr('Origin Appliance / Server Name')
