@@ -1,5 +1,4 @@
 import asyncio
-from lcconfig import ConcordiaYmlConfig
 from lchttp.json import json_dumps
 import logging
 from signal import SIGINT, SIGTERM
@@ -30,7 +29,6 @@ class ClarionServer:
         password: str,
         application: str,
     ):
-
         self.server = server
         self.user = user
         self.password = password
@@ -46,10 +44,10 @@ class ClarionServer:
                 "spec_version": "1.0",
             },
         }
-        self.queue = None
-        self.event = None
+        self.queue: asyncio.Queue | None = None
+        self.event: asyncio.Event | None = None
 
-    def run(self):
+    def run(self) -> None:
         """
         Start the synchronous ASGI server.
         """
@@ -57,13 +55,13 @@ class ClarionServer:
         asyncio.run(self.main())
         logger.info("Clarion ASGI server shutdown complete")
 
-    async def login(self):
+    async def login(self) -> None:
         """
         Login or re-login to the Clarion homeserver.
         """
         await self.client.login(self.password)
 
-    async def main(self, event=None):
+    async def main(self, event: asyncio.Event | None = None) -> None:
         """
         Start the asynchronous ASGI server.
         """
@@ -76,7 +74,7 @@ class ClarionServer:
 
         await self.login()
         asyncio.create_task(
-            self.application(self.app_scope, receive=self.queue.get, send=self.app_send),
+            self.application(self.app_scope, receive=self.queue.get, send=self.app_send),  # type: ignore[operator]
         )
         asyncio.create_task(
             self.client.sync_forever(timeout=36_000),
@@ -90,10 +88,12 @@ class ClarionServer:
         if event is None:
             await self.serve()
 
-    async def serve(self):
+    async def serve(self) -> None:
         """
         Server requests forever.
         """
+        if self.event is None or self.queue is None:
+            return
         await self.event.wait()
         await self.queue.put({
             "type": "clarion.disconnect",
@@ -101,18 +101,20 @@ class ClarionServer:
         logger.info("Stopping Clarion ASGI Server")
         await self.client.close()
 
-    async def app_send(self, message):
+    async def app_send(self, message: dict) -> None:
         """
         ASGI application `send` method: Dispatch incoming Channel messages.
         """
         logger.debug(f"app_send {message=}")
         await self.clarion_room_send(message["room"], message["body"])
 
-    async def message_callback(self, room: MatrixRoom, event: RoomMessageText):
+    async def message_callback(self, room: MatrixRoom, event: RoomMessageText) -> None:
         """
         Handle an incoming message from matrix-nio client: put it in the Queue.
         """
         logger.debug("message_callback {room=} {event=}")
+        if not self.queue:
+            return
         await self.queue.put({
             "type": "clarion.receive",
             "room": room.display_name,
@@ -173,7 +175,7 @@ class ClarionServer:
         logger.error("Clarion Homeserver not responding")
         return False
 
-    async def clarion_room_send(self, room, message):
+    async def clarion_room_send(self, room: str, message: str) -> None:
         """
         Handle an incoming `clarion.send` message from Channel,
         and forward it to Clarion.
@@ -186,7 +188,7 @@ class ClarionServer:
         }
         await self.send_room_message(room, content)
 
-    async def clarion_record_send(self, room, message):
+    async def clarion_record_send(self, room: str, message: str) -> None:
         """
         Handle an incoming `clarion.record` message from Channel,
         and forward it to Clarion.
