@@ -1,8 +1,11 @@
 import asyncio
 import importlib
+from signal import Signals
+from types import ModuleType
+from typing import Callable
 
 
-def get_application(application_name):
+def get_application(application_name: str) -> Callable | ModuleType:
     """
     Load a callable from a `module.submodule:Object.callable` string.
 
@@ -19,7 +22,7 @@ def get_application(application_name):
     return application
 
 
-def terminate(event, signal):  # pragma: no cover
+def terminate(event: asyncio.Event, signal: Signals) -> None:  # pragma: no cover
     """
     Close the event loop.
     """
