@@ -13,16 +13,17 @@ class BaseConcordiaClient:
     def publish(
         self,
         room: str,
-        payload=None,
-    ):
+        payload: dict | None = None,
+    ) -> dict:
         print(f'Publish {payload} to {room}')
-        return payload
+        return payload or {}
 
 
 class ConcordiaClient(BaseConcordiaClient):
     """
     General client class to use for Publishing / Subscribing to Concord MQ rooms.
     """
+
     ...
 
 
